@@ -16,7 +16,7 @@ class MakeItSoCLI(object):
     return a command line parser for the template
     """
     usage = getattr(self, 'usage', '%prog [options] output')
-    description = getattr(self.template_class, 'description', None)
+    description = self.template_class.get_description()
     parser = OptionParser(usage=usage, description=description)
 
     # add the variables as options
@@ -35,7 +35,7 @@ class MakeItSoCLI(object):
     """
     return dict([(key, value)
                  for key, value in options.__dict__.items()
-                 if not key.startswith('_') and value is not Undefined])
+                 if (not key.startswith('_')) and (value is not Undefined)])
 
   def parse(self, args=None, parser=None, options=None):
 
